@@ -7,7 +7,7 @@ var indexSectionsWithContent =
   4: "_abcdefghijklmnopqrstuvw~",
   5: "abcdefghiklmnopqrstuvwxy",
   6: "bcdfimopst",
-  7: "aceilmnoprstwy",
+  7: "acehilmnoprstwy",
   8: "abcdefghilmnprstuvw",
   9: "o",
   10: "ailr",
