@@ -8,6 +8,5 @@ var searchData=
   ['timestamp_5',['timestamp',['../structlibcamera_1_1FrameMetadata.html#a08999a7c7b62eeba0a36d352c314bc65',1,'libcamera::FrameMetadata']]],
   ['tonemapping_6',['toneMapping',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#a018463188c83554909e9d49d7d746ca6',1,'libcamera::ipa::ipu3::IPAActiveState']]],
   ['transferfunction_7',['transferFunction',['../classlibcamera_1_1ColorSpace.html#aad157363bb71e59a7ffcada42a501e2c',1,'libcamera::ColorSpace']]],
-  ['transform_8',['transform',['../classlibcamera_1_1CameraConfiguration.html#acd22786c435f21a2166510be47d8510b',1,'libcamera::CameraConfiguration']]],
-  ['type_9',['type',['../structlibcamera_1_1ipa__control__value__entry.html#a001952000014292562b825339b26b0ce',1,'libcamera::ipa_control_value_entry::type()'],['../structlibcamera_1_1ipa__control__info__entry.html#aa478c97c6471f027789e98d67c25f678',1,'libcamera::ipa_control_info_entry::type()']]]
+  ['type_8',['type',['../structlibcamera_1_1ipa__control__value__entry.html#a001952000014292562b825339b26b0ce',1,'libcamera::ipa_control_value_entry::type'],['../structlibcamera_1_1ipa__control__info__entry.html#aa478c97c6471f027789e98d67c25f678',1,'libcamera::ipa_control_info_entry::type']]]
 ];
