@@ -3,7 +3,7 @@ var searchData=
   ['entries_0',['entries',['../structlibcamera_1_1ipa__controls__header.html#aadafa8696be5296118d91b638ade2501',1,'libcamera::ipa_controls_header']]],
   ['error_5f_1',['error_',['../classlibcamera_1_1MappedBuffer.html#ac4b6701c923abeb049403d056ecc14b4',1,'libcamera::MappedBuffer']]],
   ['exp_2',['exp',['../unionlibcamera_1_1ipa_1_1CameraSensorHelper_1_1AnalogueGainConstants.html#a231f31e87dc21965ab767cd687ca03d2',1,'libcamera::ipa::CameraSensorHelper::AnalogueGainConstants']]],
-  ['exposure_3',['exposure',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#a7d4372130db17063ec09256672754173',1,'libcamera::ipa::ipu3::IPAActiveState::exposure()'],['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAFrameContext.html#aa500813f9d5ab7034141490cc7077890',1,'libcamera::ipa::ipu3::IPAFrameContext::exposure()']]],
+  ['exposure_3',['exposure',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#a7d4372130db17063ec09256672754173',1,'libcamera::ipa::ipu3::IPAActiveState::exposure'],['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAFrameContext.html#aa500813f9d5ab7034141490cc7077890',1,'libcamera::ipa::ipu3::IPAFrameContext::exposure']]],
   ['exposuretime_4',['ExposureTime',['../namespacelibcamera_1_1controls.html#a4e1ca45653b62cd969d4d67a741076eb',1,'libcamera::controls']]],
   ['exposurevalue_5',['ExposureValue',['../namespacelibcamera_1_1controls.html#a7b8ba16db6502e4106b646019600c98d',1,'libcamera::controls']]]
 ];
